<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                version="1.0">

  <!-- $Id: alt-makefile-dep.xsl,v 1.7 2003/09/16 15:18:39 vyt Exp $ -->
  <xsl:import href="alt-common.xsl"/>

<xsl:param name="filename-prefix" select="''"/>
<xsl:param name="output-root" select="''"/>
<!-- Additional dependencies for target website -->
<xsl:param name="add-website-depends" select="''"/>
<!-- Remove output root dir instead removing each html output file.
     Useful for removing subdirs and none html files: images, css etc. -->
<xsl:param name="remove-output-root" select="0"/>

<xsl:output method="text"/>

<xsl:template match="graphic|inlinegraphic|imagedata" mode="images-all">
  <xsl:param name="dir"/>
  <xsl:call-template name="output-root"/>
  <xsl:value-of select="$dir"/>
  <xsl:value-of select="@fileref"/>
  <xsl:text> </xsl:text>
  <xsl:if test="ancestor-or-self::*[@role][1][@role=$thumb-role]">
    <xsl:call-template name="output-root"/>
    <xsl:value-of select="$dir"/>
    <xsl:call-template name="dirname">
      <xsl:with-param name="filename" select="@fileref"/>
    </xsl:call-template>
    <xsl:value-of select="$thumb-prefix"/>
    <xsl:call-template name="not-dirname">
      <xsl:with-param name="filename" select="@fileref"/>
    </xsl:call-template>
    <xsl:text> </xsl:text>
  </xsl:if>
</xsl:template>

<xsl:template match="*|@*|text()" mode="images-all">
  <xsl:param name="dir"/>
  <xsl:apply-templates mode="images-all">
    <xsl:with-param name="dir" select="$dir"/>
  </xsl:apply-templates>
</xsl:template>

<xsl:template match="graphic|inlinegraphic|imagedata" mode="images">
  <xsl:param name="dir"/>
  <xsl:param name="page"/>
  <xsl:variable name="xmlbase">
    <xsl:call-template name="dirname">
      <xsl:with-param name="filename" select="ancestor-or-self::*[@xml:base][position()=1]/@xml:base"/>
    </xsl:call-template>
  </xsl:variable>
  <!-- vyt - checked. xml:base is not needed for _target_ images. -->
  <!-- Output image -->
  <xsl:call-template name="output-root"/>
  <xsl:value-of select="$dir"/>
  <xsl:value-of select="@fileref"/>
  <!-- Add thumb image if needed-->
  <xsl:if test="ancestor-or-self::*[@role][1][@role=$thumb-role]">
    <xsl:text> </xsl:text>
    <xsl:call-template name="output-root"/>
    <xsl:value-of select="$dir"/>
    <xsl:call-template name="dirname">
      <xsl:with-param name="filename" select="@fileref"/>
    </xsl:call-template>
    <xsl:value-of select="$thumb-prefix"/>
    <xsl:call-template name="not-dirname">
      <xsl:with-param name="filename" select="@fileref"/>
    </xsl:call-template>
  </xsl:if>
  <xsl:text>: </xsl:text>
  <!-- Source image. If @xml:base present, use it, otherwise use @page directory-->
  <xsl:choose>
    <xsl:when test="not($xmlbase='')">
      <xsl:value-of select="$xmlbase"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="dirname">
        <xsl:with-param name="filename" select="$page"/>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
  <xsl:value-of select="@fileref"/>
  <xsl:text>&#10;</xsl:text>
</xsl:template>

<xsl:template match="*|@*|text()" mode="images">
  <xsl:param name="dir"/>
  <xsl:param name="page"/>
  <xsl:apply-templates mode="images">
    <xsl:with-param name="dir" select="$dir"/>
    <xsl:with-param name="page" select="$page"/>
  </xsl:apply-templates>
</xsl:template>

<xsl:template match="@page" mode="tuned">
  <xsl:value-of select="."/>
  <xsl:text>-tuned </xsl:text>
</xsl:template>

<xsl:template match="autolayout">
  <xsl:text>website: </xsl:text>
  <xsl:value-of select="$add-website-depends"/>
  <xsl:text> </xsl:text>
  <xsl:apply-templates select="toc" mode="all"/>
  <xsl:apply-templates select="notoc" mode="all"/>
  <xsl:text>&#10;&#10;</xsl:text>
  <xsl:apply-templates select="toc"/>
  <xsl:apply-templates select="notoc"/>
  <xsl:text>&#10;</xsl:text>
  <xsl:text>distclean: clean
&#9;-rm -f </xsl:text>
  <xsl:text>autolayout.xml depends.tabular</xsl:text>
  <xsl:text>&#10;&#10;</xsl:text>
  <xsl:text>clean:&#10;</xsl:text>
  <xsl:choose>
    <xsl:when test="$remove-output-root and not($output-root='')">
      <xsl:text>&#9;-rm -rf </xsl:text>
      <xsl:call-template name="output-root"/>
      <xsl:text> </xsl:text>
      <xsl:apply-templates select="//@page" mode="tuned"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>&#9;-rm -f </xsl:text>
      <xsl:apply-templates select="toc" mode="all"/>
      <xsl:apply-templates select="notoc" mode="all"/>
      <xsl:apply-templates select="//@page" mode="tuned"/>
    </xsl:otherwise>
  </xsl:choose>
  <xsl:text>&#10;&#10;</xsl:text>
</xsl:template>

<xsl:template match="toc">
<!--
  <xsl:apply-templates select="." mode="calculate-dir"/>
-->
  <xsl:call-template name="output-root"/>
  <xsl:value-of select="@dir"/>
  <xsl:value-of select="$filename-prefix"/>
  <xsl:value-of select="@filename"/>
  <xsl:text>: </xsl:text>
  <xsl:value-of select="@page"/>
  <xsl:text>&#10;</xsl:text>
  <xsl:apply-templates select=".//tocentry"/>
  <xsl:apply-templates select="document(@page)" mode="images">
    <xsl:with-param name="dir" select="@dir"/>
    <xsl:with-param name="page" select="@page"/>
  </xsl:apply-templates>
</xsl:template>

<xsl:template match="tocentry|notoc">
<!--
  <xsl:apply-templates select="." mode="calculate-dir"/>
-->
  <xsl:if test="@filename">
    <xsl:call-template name="output-root"/>
    <xsl:value-of select="@dir"/>
    <xsl:value-of select="$filename-prefix"/>
    <xsl:value-of select="@filename"/>
    <xsl:text>: </xsl:text>
    <xsl:value-of select="@page"/>
    <xsl:text>&#10;</xsl:text>
    <xsl:apply-templates select="document(@page)" mode="images">
      <xsl:with-param name="dir" select="@dir"/>
      <xsl:with-param name="page" select="@page"/>
    </xsl:apply-templates>
  </xsl:if>
</xsl:template>

<xsl:template match="toc" mode="all">
  <xsl:apply-templates select=".//tocentry" mode="all"/>
<!--
  <xsl:apply-templates select="." mode="calculate-dir"/>
-->
  <xsl:call-template name="output-root"/>
  <xsl:value-of select="@dir"/>
  <xsl:value-of select="$filename-prefix"/>
  <xsl:value-of select="@filename"/>
  <xsl:text> </xsl:text>
  <xsl:apply-templates select="document(@page)" mode="images-all">
    <xsl:with-param name="dir" select="@dir"/>
  </xsl:apply-templates>
</xsl:template>

<xsl:template match="tocentry|notoc" mode="all">
<!--
  <xsl:apply-templates select="." mode="calculate-dir"/>
-->
  <!-- FIXME: vyt - if filename not present, it must be index.html ? -->
  <xsl:if test="@filename">
    <xsl:call-template name="output-root"/>
    <xsl:value-of select="@dir"/>
    <xsl:value-of select="$filename-prefix"/>
    <xsl:value-of select="@filename"/>
    <xsl:text> </xsl:text>
    <xsl:apply-templates select="document(@page)" mode="images-all">
      <xsl:with-param name="dir" select="@dir"/>
    </xsl:apply-templates>
  </xsl:if>
</xsl:template>

<xsl:template match="*" mode="calculate-dir">
  <xsl:choose>
    <xsl:when test="starts-with(@dir, '/')">
      <!-- if the directory on this begins with a "/", we're done... -->
      <xsl:value-of select="substring-after(@dir, '/')"/>
<!--
      <xsl:if test="@dir != '/'">
        <xsl:text>/</xsl:text>
      </xsl:if>
-->
    </xsl:when>

    <xsl:when test="parent::*">
      <!-- if there's a parent, try it -->
      <xsl:apply-templates select="parent::*" mode="calculate-dir"/>
      <xsl:if test="@dir">
        <xsl:value-of select="@dir"/>
<!--
        <xsl:text>/</xsl:text>
-->
      </xsl:if>
    </xsl:when>

    <xsl:otherwise>
      <xsl:if test="@dir">
        <xsl:value-of select="@dir"/>
<!--
        <xsl:text>/</xsl:text>
-->
      </xsl:if>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template name="output-root">
  <xsl:if test="$output-root != ''">
    <xsl:value-of select="$output-root"/>
    <xsl:text>/</xsl:text>
  </xsl:if>
</xsl:template>


</xsl:stylesheet>
